@@ -337,6 +337,9 @@ class CinacPredictor:
             n_cells = cinac_recording.get_n_cells()
             n_frames = cinac_recording.get_n_frames()
 
+            # a 1d or 2d np.array of n_cells in the 1d
+            predictions_by_cell = None
+
             network_identifiers = []
             for file_names, cells_to_predict in model_files_dict.items():
                 json_model_file_name, weights_file_name, network_identifier = file_names
@@ -365,14 +368,14 @@ class CinacPredictor:
                     print(f"No cells loaded for {cinac_recording.identifier}")
                     continue
 
-                # print(f"transients_prediction_from_movie n_frames {n_frames}")
                 # we keep the original number of cells, so if a different segmentation was used another prediction,
                 # we can still compare it using the indices we know
-                if cell_type_classifier_mode:
-                    # will be initiated later when the number of classes will be known
-                    predictions_by_cell = None  # np.zeros(n_cells)
-                else:
-                    predictions_by_cell = np.zeros((n_cells, n_frames))
+                if predictions_by_cell is None:
+                    if cell_type_classifier_mode:
+                        # will be initiated later when the number of classes will be known
+                        predictions_by_cell = None  # np.zeros(n_cells)
+                    else:
+                        predictions_by_cell = np.zeros((n_cells, n_frames))
 
                 # loading model
                 # Model reconstruction from JSON file
